==> qopenvpn-1.3.2-3-any.pkg.tar.xz: usr/lib/python3.6/site-packages/qopenvpn/languages/qopenvpn_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>QOpenVPNLogViewer</name>
    <message>
        <location filename="ui_qopenvpnlogviewer.py" line="63"/>
        <source>QOpenVPN Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnlogviewer.py" line="64"/>
        <source>IP address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnlogviewer.py" line="65"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QOpenVPNSettings</name>
    <message>
        <location filename="ui_qopenvpnsettings.py" line="71"/>
        <source>QOpenVPN Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnsettings.py" line="72"/>
        <source>VPN name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnsettings.py" line="73"/>
        <source>Show warning when disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnsettings.py" line="74"/>
        <source>Use sudo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ui_qopenvpnsettings.py" line="75"/>
        <source>Sudo command:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QOpenVPNWidget</name>
    <message>
        <location filename="qopenvpn.py" line="101"/>
        <source>&amp;Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="103"/>
        <source>S&amp;top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="105"/>
        <source>S&amp;ettings ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="109"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="107"/>
        <source>Show &amp;logs ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="149"/>
        <source>QOpenVPN - Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="149"/>
        <source>You have been disconnected from VPN!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="202"/>
        <source>QOpenVPN - Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qopenvpn.py" line="202"/>
        <source>You are still connected to VPN! Do you really want to quit QOpenVPN GUI (OpenVPN service will keep running in background)?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qopenvpn-2.0.0-6-any.pkg.tar.xz: usr/lib/python3.10/site-packages/qopenvpn/languages/qopenvpn_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>QOpenVPNLogViewer</name>
    <message>
        <location filename="../ui_qopenvpnlogviewer.py" line="49"/>
        <source>QOpenVPN Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnlogviewer.py" line="50"/>
        <source>IP address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnlogviewer.py" line="51"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QOpenVPNSettings</name>
    <message>
        <location filename="../ui_qopenvpnsettings.py" line="57"/>
        <source>QOpenVPN Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnsettings.py" line="58"/>
        <source>VPN name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnsettings.py" line="59"/>
        <source>Show warning when disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnsettings.py" line="60"/>
        <source>Use sudo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui_qopenvpnsettings.py" line="61"/>
        <source>Sudo command:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QOpenVPNWidget</name>
    <message>
        <location filename="../__main__.py" line="151"/>
        <source>&amp;Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="153"/>
        <source>S&amp;top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="155"/>
        <source>S&amp;ettings ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="159"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="157"/>
        <source>Show &amp;logs ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="199"/>
        <source>QOpenVPN - Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="199"/>
        <source>You have been disconnected from VPN!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="263"/>
        <source>QOpenVPN - Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../__main__.py" line="263"/>
        <source>You are still connected to VPN! Do you really want to quit QOpenVPN GUI (OpenVPN service will keep running in background)?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
